@@ -57,7 +57,7 @@ class FfmpegProcess:
             self._process = subprocess.Popen(
                 self._ffmpeg_args,
                 stdout=subprocess.PIPE,
-                stderr=f,
+                #stderr=f,
             )
 
         input_file_info = FileInfoProvider(filepath)
@@ -83,7 +83,7 @@ class FfmpegProcess:
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
-            log.info("[KeyboardInterrupt] FFmpeg process killed. Exiting Better FFmpeg Progress.")
+            print("[KeyboardInterrupt] FFmpeg process killed. Exiting Better FFmpeg Progress.")
             sys.exit(0)
 
             # width, height = os.get_terminal_size()
